==> kie-wb-common-cli-project-migration-7.7.0.Final-sources.jar: org/kie/workbench/common/project/config/MigrationWorkspaceProjectMigrationServiceImpl.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.project.config;

import javax.enterprise.event.Event;
import javax.enterprise.inject.Alternative;
import javax.inject.Inject;
import javax.inject.Named;

import org.guvnor.common.services.project.backend.server.WorkspaceProjectMigrationServiceImpl;
import org.guvnor.common.services.project.events.NewProjectEvent;
import org.guvnor.common.services.project.model.Module;
import org.guvnor.common.services.project.service.ModuleService;
import org.uberfire.io.IOService;

@Alternative
public class MigrationWorkspaceProjectMigrationServiceImpl extends WorkspaceProjectMigrationServiceImpl {

    public MigrationWorkspaceProjectMigrationServiceImpl() {
        super();
    }

    @Inject
    public MigrationWorkspaceProjectMigrationServiceImpl(final MigrationWorkspaceProjectServiceImpl workspaceProjectService,
                                                         final MigrationRepositoryServiceImpl repositoryService,
                                                         final MigrationOrganizationalUnitServiceImpl organizationalUnitService,
                                                         final Event<NewProjectEvent> newProjectEvent,
                                                         final MigrationRepositoryCopierImpl repositoryCopier,
                                                         final ModuleService<? extends Module> moduleService,
                                                         final @Named("ioStrategy") IOService ioService) {
        super(workspaceProjectService,
              repositoryService,
              organizationalUnitService,
              newProjectEvent,
              repositoryCopier,
              moduleService,
              ioService);
    }
}

==> kie-wb-common-cli-project-migration-7.8.0.Final-sources.jar: org/kie/workbench/common/project/config/MigrationWorkspaceProjectMigrationServiceImpl.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.project.config;

import javax.enterprise.event.Event;
import javax.enterprise.inject.Alternative;
import javax.inject.Inject;

import org.guvnor.common.services.project.backend.server.WorkspaceProjectMigrationServiceImpl;
import org.guvnor.common.services.project.backend.server.utils.PathUtil;
import org.guvnor.common.services.project.events.NewProjectEvent;
import org.guvnor.common.services.project.model.Module;
import org.guvnor.common.services.project.service.ModuleService;

@Alternative
public class MigrationWorkspaceProjectMigrationServiceImpl extends WorkspaceProjectMigrationServiceImpl {

    public MigrationWorkspaceProjectMigrationServiceImpl() {
        super();
    }

    @Inject
    public MigrationWorkspaceProjectMigrationServiceImpl(final MigrationWorkspaceProjectServiceImpl workspaceProjectService,
                                                         final MigrationRepositoryServiceImpl repositoryService,
                                                         final MigrationOrganizationalUnitServiceImpl organizationalUnitService,
                                                         final PathUtil pathUtil,
                                                         final Event<NewProjectEvent> newProjectEvent,
                                                         final ModuleService<? extends Module> moduleService) {
        super(workspaceProjectService,
              repositoryService,
              organizationalUnitService,
              pathUtil,
              newProjectEvent,
              moduleService);
    }
}
